package com.ruoyi.custclient.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.LabelType;
import org.apache.ibatis.annotations.Mapper;

/**
 * 标签组Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-17
 */
public interface LabelTypeMapper extends BaseMapper<LabelType> {
    /**
     * 查询标签组
     *
     * @param id 标签组主键
     * @return 标签组
     */
    public LabelType selectLabelTypeById(Long id);

    /**
     * 查询标签组列表
     *
     * @param labelType 标签组
     * @return 标签组集合
     */
    public List<LabelType> selectLabelTypeList(LabelType labelType);

    /**
     * 新增标签组
     *
     * @param labelType 标签组
     * @return 结果
     */
    public int insertLabelType(LabelType labelType);

    /**
     * 修改标签组
     *
     * @param labelType 标签组
     * @return 结果
     */
    public int updateLabelType(LabelType labelType);

    /**
     * 删除标签组
     *
     * @param id 标签组主键
     * @return 结果
     */
    public int deleteLabelTypeById(Long id);

    /**
     * 批量删除标签组
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabelTypeByIds(Long[] ids);
}
